import click
import dkim


@click.command()
@click.argument("eml_filename", type=click.File("rb"))
def main(eml_filename):
    message = eml_filename.read()

    if b"DKIM-Signature: " not in message:
        print("This email does not have a DKIM-Signature header")
        return

    verifier = dkim.DKIM(message=message)
    try:
        if verifier.verify():
            print("DKIM verified successfully")
        else:
            print("DKIM failed to verify")
    except Exception as e:
        print("Error verifying DKIM")
        print(e)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['check_dkim']

package_data = \
{'': ['*']}

install_requires = \
['click', 'dkimpy']

entry_points = \
{'console_scripts': ['check-dkim = check_dkim:main']}

setup_kwargs = {
    'name': 'check-dkim',
    'version': '0.1.0',
    'description': 'A simple CLI script to verify DKIM signatures on EML files',
    'long_description': '# check-dkim\n\nA simple CLI script to verify DKIM signatures on EML files.\n',
    'author': 'Micah Lee',
    'author_email': 'micah@micahflee.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
